@@ -99,9 +99,9 @@ to MATLAB&reg;, a registered trademark of The MathWorks, Inc.
 """
 from __future__ import generators
 
-__version__  = '1.0.0'
-__revision__ = '$Revision: 8503 $'
-__date__     = '$Date: 2010-07-06 08:56:31 -0500 (Tue, 06 Jul 2010) $'
+__version__  = '1.0.1'
+__revision__ = '$Revision: 8897 $'
+__date__     = '$Date: 2011-01-06 05:50:07 -0800 (Thu, 06 Jan 2011) $'
 
 import os, re, shutil, subprocess, sys, warnings
 import distutils.sysconfig
@@ -632,24 +632,49 @@ class RcParams(dict):
 
     validate = dict([ (key, converter) for key, (default, converter) in \
                      defaultParams.iteritems() ])
+    msg_depr = "%s is deprecated and replaced with %s; please use the latter."
+    msg_depr_ignore = "%s is deprecated and ignored. Use %s"
 
     def __setitem__(self, key, val):
         try:
-            if key in _deprecated_map.keys():
+            if key in _deprecated_map:
                 alt = _deprecated_map[key]
-                warnings.warn('%s is deprecated in matplotlibrc. Use %s \
-instead.'% (key, alt))
+                warnings.warn(self.msg_depr % (key, alt))
                 key = alt
             elif key in _deprecated_ignore_map:
                 alt = _deprecated_ignore_map[key]
-                warnings.warn('%s is deprecated. Use %s instead.'% (key, alt))
+                warnings.warn(self.msg_depr_ignore % (key, alt))
                 return
             cval = self.validate[key](val)
             dict.__setitem__(self, key, cval)
         except KeyError:
             raise KeyError('%s is not a valid rc parameter.\
-See rcParams.keys() for a list of valid parameters.'%key)
+See rcParams.keys() for a list of valid parameters.' % (key,))
 
+    def __getitem__(self, key):
+        if key in _deprecated_map:
+            alt = _deprecated_map[key]
+            warnings.warn(self.msg_depr % (key, alt))
+            key = alt
+        elif key in _deprecated_ignore_map:
+            alt = _deprecated_ignore_map[key]
+            warnings.warn(self.msg_depr_ignore % (key, alt))
+            key = alt
+        return dict.__getitem__(self, key)
+
+    def keys(self):
+        """
+        Return sorted list of keys.
+        """
+        k = dict.keys(self)
+        k.sort()
+        return k
+
+    def values(self):
+        """
+        Return values in order of sorted keys.
+        """
+        return [self[k] for k in self.keys()]
 
 def rc_params(fail_on_error=False):
     'Return the default params updated from the values in the rc file'
@@ -737,6 +762,7 @@ Please do not ask for support with these customizations active.
 
 # this is the instance used by the matplotlib classes
 rcParams = rc_params()
+rcParamsOrig = rcParams.copy()
 
 rcParamsDefault = RcParams([ (key, default) for key, (default, converter) in \
                     defaultParams.iteritems() ])
@@ -810,19 +836,27 @@ def rc(group, **kwargs):
         for k,v in kwargs.items():
             name = aliases.get(k) or k
             key = '%s.%s' % (g, name)
-            if key not in rcParams:
+            try:
+                rcParams[key] = v
+            except KeyError:
                 raise KeyError('Unrecognized key "%s" for group "%s" and name "%s"' %
                                (key, g, name))
 
-            rcParams[key] = v
-
 def rcdefaults():
     """
-    Restore the default rc params - the ones that were created at
-    matplotlib load time.
+    Restore the default rc params - these are not the params loaded by
+    the rc file, but mpl's internal params.  See rc_file_defaults for
+    reloading the default params from the rc file
     """
     rcParams.update(rcParamsDefault)
 
+def rc_file_defaults():
+    """
+    Restore the default rc params from the original matplotlib rc that
+    was loaded
+    """
+    rcParams.update(rcParamsOrig)
+
 _use_error_msg = """ This call to matplotlib.use() has no effect
 because the the backend has already been chosen;
 matplotlib.use() must be called *before* pylab, matplotlib.pyplot,
