@@ -1423,11 +1423,9 @@ class Axis(artist.Artist):
             self.set_minor_formatter(mticker.FixedFormatter(ticklabels))
             ticks = self.get_minor_ticks()
         else:
-            self.set_major_formatter( mticker.FixedFormatter(ticklabels) )
+            self.set_major_formatter(mticker.FixedFormatter(ticklabels))
             ticks = self.get_major_ticks()
 
-        self.set_major_formatter( mticker.FixedFormatter(ticklabels) )
-
         ret1 = []
         ret2 = []
         for i, tick in enumerate(ticks):
@@ -1698,11 +1696,21 @@ class XAxis(Axis):
         return self.axes.viewLim.intervalx
 
     def set_view_interval(self, vmin, vmax, ignore=False):
+        """
+        If *ignore* is *False*, the order of vmin, vmax
+        does not matter; the original axis orientation will
+        be preserved.
+        """
         if ignore:
             self.axes.viewLim.intervalx = vmin, vmax
         else:
             Vmin, Vmax = self.get_view_interval()
-            self.axes.viewLim.intervalx = min(vmin, Vmin), max(vmax, Vmax)
+            if Vmin < Vmax:
+                self.axes.viewLim.intervalx = (min(vmin, vmax, Vmin),
+                                               max(vmin, vmax, Vmax))
+            else:
+                self.axes.viewLim.intervalx = (max(vmin, vmax, Vmin),
+                                               min(vmin, vmax, Vmax))
 
     def get_minpos(self):
         return self.axes.dataLim.minposx
@@ -1888,11 +1896,12 @@ class YAxis(Axis):
 
     def set_ticks_position(self, position):
         """
-        Set the ticks position (left, right, both or default)
-        both sets the ticks to appear on both positions, but
-        does not change the tick labels.
-        default resets the tick positions to the default:
-        ticks on both positions, labels on the left.
+        Set the ticks position (left, right, both, default or none)
+        'both' sets the ticks to appear on both positions, but does not
+        change the tick labels.  'default' resets the tick positions to
+        the default: ticks on both positions, labels at left.  'none'
+        can be used if you don't want any ticks. 'none' and 'both'
+        affect only the ticks, not the labels.
 
         ACCEPTS: [ 'left' | 'right' | 'both' | 'default' | 'none' ]
         """
@@ -1906,8 +1915,8 @@ class YAxis(Axis):
             self.set_tick_params(which='both', right=True,
                                  left=True)
         elif position == 'none':
-            self.set_tick_params(which='both', right=False, labelright=False,
-                                 left=False, labelleft=False)
+            self.set_tick_params(which='both', right=False,
+                                 left=False)
         elif position == 'default':
             self.set_tick_params(which='both', right=True, labelright=False,
                                  left=True, labelleft=True)
@@ -1948,11 +1957,21 @@ class YAxis(Axis):
         return self.axes.viewLim.intervaly
 
     def set_view_interval(self, vmin, vmax, ignore=False):
+        """
+        If *ignore* is *False*, the order of vmin, vmax
+        does not matter; the original axis orientation will
+        be preserved.
+        """
         if ignore:
             self.axes.viewLim.intervaly = vmin, vmax
         else:
             Vmin, Vmax = self.get_view_interval()
-            self.axes.viewLim.intervaly = min(vmin, Vmin), max(vmax, Vmax)
+            if Vmin < Vmax:
+                self.axes.viewLim.intervaly = (min(vmin, vmax, Vmin),
+                                               max(vmin, vmax, Vmax))
+            else:
+                self.axes.viewLim.intervaly = (max(vmin, vmax, Vmin),
+                                               min(vmin, vmax, Vmax))
 
     def get_minpos(self):
         return self.axes.dataLim.minposy
@@ -1985,5 +2004,3 @@ class YAxis(Axis):
                 self.axes.dataLim.intervaly = ymin, ymax
             if not viewMutated:
                 self.axes.viewLim.intervaly = ymin, ymax
-
-
