@@ -20,10 +20,11 @@ del pygtk_version_required
 _new_tooltip_api =  (gtk.pygtk_version[1] >= 12)
 
 import matplotlib
-from matplotlib import verbose
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase, \
      FigureManagerBase, FigureCanvasBase, NavigationToolbar2, cursors, TimerBase
+from matplotlib.backend_bases import ShowBase
+
 from matplotlib.backends.backend_gdk import RendererGDK, FigureCanvasGDK
 from matplotlib.cbook import is_string_like, is_writable_file_like
 from matplotlib.colors import colorConverter
@@ -32,6 +33,7 @@ from matplotlib.widgets import SubplotTool
 
 from matplotlib import lines
 from matplotlib import cbook
+from matplotlib import verbose
 
 backend_version = "%d.%d.%d" % gtk.pygtk_version
 
@@ -65,17 +67,12 @@ def draw_if_interactive():
             figManager.canvas.draw_idle()
 
 
-def show(mainloop=True):
-    """
-    Show all the figures and enter the gtk main loop
-    This should be the last line of your script
-    """
-    for manager in Gcf.get_all_fig_managers():
-        manager.window.show()
+class Show(ShowBase):
+    def mainloop(self):
+        if gtk.main_level() == 0:
+            gtk.main()
 
-    if mainloop and gtk.main_level() == 0 and \
-                            len(Gcf.get_all_fig_managers())>0:
-        gtk.main()
+show = Show()
 
 def new_figure_manager(num, *args, **kwargs):
     """
@@ -104,6 +101,9 @@ class TimerGTK(TimerBase):
         functions add_callback and remove_callback can be used.
     '''
     def _timer_start(self):
+        # Need to stop it, otherwise we potentially leak a timer id that will
+        # never be stopped.
+        self._timer_stop()
         self._timer = gobject.timeout_add(self._interval, self._on_timer)
 
     def _timer_stop(self):
@@ -112,6 +112,7 @@ class TimerGTK(TimerBase):
             self._timer = None
 
     def _timer_set_interval(self):
+        # Only stop and restart it if the timer has already been started
         if self._timer is not None:
             self._timer_stop()
             self._timer_start()
@@ -619,7 +620,7 @@ class NavigationToolbar2GTK(NavigationToolbar2, gtk.Toolbar):
         self.canvas.window.set_cursor(cursord[cursor])
 
     def release(self, event):
-        try: del self._imageBack
+        try: del self._pixmapBack
         except AttributeError: pass
 
     def dynamic_update(self):
@@ -643,7 +644,7 @@ class NavigationToolbar2GTK(NavigationToolbar2, gtk.Toolbar):
 
         rect = [int(val)for val in min(x0,x1), min(y0, y1), w, h]
         try:
-            lastrect, imageBack = self._imageBack
+            lastrect, pixmapBack = self._pixmapBack
         except AttributeError:
             #snap image back
             if event.inaxes is None:
@@ -653,9 +654,10 @@ class NavigationToolbar2GTK(NavigationToolbar2, gtk.Toolbar):
             l,b,w,h = [int(val) for val in ax.bbox.bounds]
             b = int(height)-(b+h)
             axrect = l,b,w,h
-            self._imageBack = axrect, drawable.get_image(*axrect)
+            self._pixmapBack = axrect, gtk.gdk.Pixmap(drawable, w, h)
+            self._pixmapBack[1].draw_drawable(gc, drawable, l, b, 0, 0, w, h)
         else:
-            drawable.draw_image(gc, imageBack, 0, 0, *lastrect)
+            drawable.draw_drawable(gc, pixmapBack, 0, 0, *lastrect)
         drawable.draw_rectangle(gc, False, *rect)
 
 
@@ -1228,7 +1230,6 @@ except:
     window_icon = None
     verbose.report('Could not load matplotlib icon: %s' % sys.exc_info()[1])
 
-
 def error_msg_gtk(msg, parent=None):
     if parent is not None: # find the toplevel gtk.Window
         parent = parent.get_toplevel()
