@@ -2,11 +2,12 @@ from __future__ import division
 
 import os
 import numpy
-import MacOS
 
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase,\
      FigureManagerBase, FigureCanvasBase, NavigationToolbar2
+from matplotlib.backend_bases import ShowBase
+
 from matplotlib.cbook import maxdict
 from matplotlib.figure import Figure
 from matplotlib.path import Path
@@ -20,19 +21,16 @@ from matplotlib.widgets import SubplotTool
 import matplotlib
 from matplotlib.backends import _macosx
 
-def show():
-    """Show all the figures and enter the Cocoa mainloop.
-    This function will not return until all windows are closed or
-    the interpreter exits."""
-    # Having a Python-level function "show" wrapping the built-in
-    # function "show" in the _macosx extension module allows us to
-    # to add attributes to "show". This is something ipython does.
-    _macosx.show()
+class Show(ShowBase):
+    def mainloop(self):
+        _macosx.show()
+
+show = Show()
 
 class RendererMac(RendererBase):
     """
     The renderer handles drawing/rendering operations. Most of the renderer's
-    methods forwards the command to the renderer's graphics context. The
+    methods forward the command to the renderer's graphics context. The
     renderer does not wrap a C object and is written in pure Python.
     """
 
@@ -51,13 +49,13 @@ class RendererMac(RendererBase):
 
     def draw_path(self, gc, path, transform, rgbFace=None):
         if rgbFace is not None:
-            rgbFace = tuple(rgbFace)
+            rgbFace = tuple(rgbFace[:3])
         linewidth = gc.get_linewidth()
         gc.draw_path(path, transform, linewidth, rgbFace)
 
     def draw_markers(self, gc, marker_path, marker_trans, path, trans, rgbFace=None):
         if rgbFace is not None:
-            rgbFace = tuple(rgbFace)
+            rgbFace = tuple(rgbFace[:3])
         linewidth = gc.get_linewidth()
         gc.draw_markers(marker_path, marker_trans, path, trans, linewidth, rgbFace)
 
@@ -230,7 +228,7 @@ def new_figure_manager(num, *args, **kwargs):
     """
     Create a new figure manager instance
     """
-    if not MacOS.WMAvailable():
+    if not _macosx.verify_main_display():
         import warnings
         warnings.warn("Python is not installed as a framework. The MacOSX backend may not work correctly if Python is not installed as a framework. Please see the Python documentation for more information on installing Python as a framework on Mac OS X")
     FigureClass = kwargs.pop('FigureClass', Figure)
