@@ -9,6 +9,8 @@ from matplotlib.cbook import is_string_like, onetrue
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase, \
      FigureManagerBase, FigureCanvasBase, NavigationToolbar2, IdleEvent, \
      cursors, TimerBase
+from matplotlib.backend_bases import ShowBase
+
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.figure import Figure
 from matplotlib.mathtext import MathTextParser
@@ -56,22 +58,12 @@ def _create_qApp():
 
 _create_qApp.qAppCreatedHere = False
 
-def show():
-    """
-    Show all the figures and enter the qt main loop
-    This should be the last line of your script
-    """
-    for manager in Gcf.get_all_fig_managers():
-        manager.window.show()
+class Show(ShowBase):
+    def mainloop(self):
+        if _create_qApp.qAppCreatedHere:
+            QtGui.qApp.exec_()
 
-    if DEBUG: print 'Inside show'
-
-    figManager =  Gcf.get_active()
-    if figManager != None:
-        figManager.canvas.draw()
-
-    if _create_qApp.qAppCreatedHere:
-        QtGui.qApp.exec_()
+show = Show()
 
 
 def new_figure_manager( num, *args, **kwargs ):
@@ -158,6 +150,7 @@ class FigureCanvasQT( QtGui.QWidget, FigureCanvasBase ):
         FigureCanvasBase.enter_notify_event(self, event)
 
     def leaveEvent(self, event):
+        QtGui.QApplication.restoreOverrideCursor()
         FigureCanvasBase.leave_notify_event(self, event)
 
     def mousePressEvent( self, event ):
@@ -189,7 +182,7 @@ class FigureCanvasQT( QtGui.QWidget, FigureCanvasBase ):
         y = self.figure.bbox.height - event.y()
         # from QWheelEvent::delta doc
         steps = event.delta()/120
-        if (event.orientation() == Qt.Qt.Vertical):
+        if (event.orientation() == QtCore.Qt.Vertical):
             FigureCanvasBase.scroll_event( self, x, y, steps)
             if DEBUG: print 'scroll event : delta = %i, steps = %i ' % (event.delta(),steps)
 
@@ -370,6 +363,9 @@ class FigureManagerQT( FigureManagerBase ):
         'set the canvas size in pixels'
         self.window.resize(width, height)
 
+    def show(self):
+        self.window.show()
+
     def destroy( self, *args ):
         if self.window._destroying: return
         self.window._destroying = True
@@ -454,7 +450,7 @@ class NavigationToolbar2QT( NavigationToolbar2, QtGui.QToolBar ):
                         text += ": "+ylabel
                     text += " (%s)"
                 elif ylabel:
-                    text = "%s (%s)" % ylabel
+                    text = "%%s (%s)" % ylabel
                 else:
                     text = "%s"
                 titles.append(text % repr(axes))
