@@ -118,7 +118,7 @@ class RendererSVG(RendererBase):
                 '<rect x="0" y="0" width="%d" height="%d" fill="%s"/>' %
                 (HATCH_SIZE+1, HATCH_SIZE+1, fill))
             path = '<path d="%s" fill="%s" stroke="%s" stroke-width="1.0"/>' % (
-                path_data, rgb2hex(gc.get_rgb()[:3]), rgb2hex(gc.get_rgb()[:3]))
+                path_data, rgb2hex(gc.get_rgb()), rgb2hex(gc.get_rgb()))
             self._svgwriter.write(path)
             self._svgwriter.write('\n  </pattern>\n</defs>')
             self._hatchd[dictkey] = id
@@ -135,7 +135,7 @@ class RendererSVG(RendererBase):
             if rgbFace is None:
                 fill = 'none'
             else:
-                fill = rgb2hex(rgbFace[:3])
+                fill = rgb2hex(rgbFace)
 
         offset, seq = gc.get_dashes()
         if seq is None:
@@ -149,7 +149,7 @@ class RendererSVG(RendererBase):
             return 'fill: %s; stroke: %s; stroke-width: %f; ' \
                 'stroke-linejoin: %s; stroke-linecap: %s; %s opacity: %f' % (
                          fill,
-                         rgb2hex(gc.get_rgb()[:3]),
+                         rgb2hex(gc.get_rgb()),
                          linewidth,
                          gc.get_joinstyle(),
                          _capstyle_d[gc.get_capstyle()],
@@ -325,6 +325,11 @@ class RendererSVG(RendererBase):
         # opposite edge.  Underlying these three gradients is a solid
         # triangle whose color is the average of all three points.
 
+        avg_color = np.sum(colors[:, :], axis=0) / 3.0
+        # Just skip fully-transparent triangles
+        if avg_color[-1] == 0.0:
+            return
+
         trans_and_flip = self._make_flip_transform(trans)
         tpoints = trans_and_flip.transform(points)
         write = self._svgwriter.write
@@ -334,7 +339,7 @@ class RendererSVG(RendererBase):
             x1, y1 = points[i]
             x2, y2 = points[(i + 1) % 3]
             x3, y3 = points[(i + 2) % 3]
-            c = colors[i][:3]
+            c = colors[i][:]
 
             if x2 == x3:
                 xb = x2
@@ -352,8 +357,8 @@ class RendererSVG(RendererBase):
 
             write('<linearGradient id="GR%x_%d" x1="%f" y1="%f" x2="%f" y2="%f" gradientUnits="userSpaceOnUse">' %
                   (self._n_gradients, i, x1, y1, xb, yb))
-            write('<stop offset="0" stop-color="%s" stop-opacity="1.0"/>' % rgb2hex(c))
-            write('<stop offset="1" stop-color="%s" stop-opacity="0.0"/>' % rgb2hex(c))
+            write('<stop offset="0" style="stop-color:%s;stop-opacity:%f"/>' % (rgb2hex(c), c[-1]))
+            write('<stop offset="1" style="stop-color:%s;stop-opacity:0"/>' % rgb2hex(c))
             write('</linearGradient>')
 
         # Define the triangle itself as a "def" since we use it 4 times
@@ -361,11 +366,11 @@ class RendererSVG(RendererBase):
               (self._n_gradients, x1, y1, x2, y2, x3, y3))
         write('</defs>\n')
 
-        avg_color = np.sum(colors[:, :3], axis=0) / 3.0
-        write('<use xlink:href="#GT%x" fill="%s"/>\n' %
-              (self._n_gradients, rgb2hex(avg_color)))
+        avg_color = np.sum(colors[:, :], axis=0) / 3.0
+        write('<use xlink:href="#GT%x" fill="%s" fill-opacity="%f"/>\n' %
+              (self._n_gradients, rgb2hex(avg_color), avg_color[-1]))
         for i in range(3):
-            write('<use xlink:href="#GT%x" fill="url(#GR%x_%d)" filter="url(#colorAdd)"/>\n' %
+            write('<use xlink:href="#GT%x" fill="url(#GR%x_%d)" fill-opacity="1" filter="url(#colorAdd)"/>\n' %
                   (self._n_gradients, self._n_gradients, i))
 
         self._n_gradients += 1
@@ -389,7 +394,12 @@ class RendererSVG(RendererBase):
         write('</g>\n')
 
     def draw_image(self, gc, x, y, im):
-        # MGDTODO: Support clippath here
+        clipid = self._get_gc_clip_svg(gc)
+        if clipid is None:
+            clippath = ''
+        else:
+            clippath = 'clip-path="url(#%s)"' % clipid
+
         trans = [1,0,0,1,0,0]
         transstr = ''
         if rcParams['svg.image_noscale']:
@@ -410,7 +420,9 @@ class RendererSVG(RendererBase):
             self._svgwriter.write('<a xlink:href="%s">' % url)
         self._svgwriter.write (
             '<image x="%f" y="%f" width="%f" height="%f" '
-            '%s xlink:href="'%(x/trans[0], (self.height-y)/trans[3]-h, w, h, transstr)
+            '%s %s xlink:href="' % (
+                x/trans[0], (self.height-y)/trans[3]-h, w, h,
+                transstr, clippath)
             )
 
         if rcParams['svg.image_inline']:
@@ -462,7 +474,7 @@ class RendererSVG(RendererBase):
         glyph_map=self._glyph_map
 
         text2path = self._text2path
-        color = rgb2hex(gc.get_rgb()[:3])
+        color = rgb2hex(gc.get_rgb())
         fontsize = prop.get_size_in_points()
 
         write = self._svgwriter.write
@@ -585,7 +597,7 @@ class RendererSVG(RendererBase):
         y -= font.get_descent() / 64.0
 
         fontsize = prop.get_size_in_points()
-        color = rgb2hex(gc.get_rgb()[:3])
+        color = rgb2hex(gc.get_rgb())
         write = self._svgwriter.write
 
         if rcParams['svg.embed_char_paths']:
@@ -723,7 +735,7 @@ class RendererSVG(RendererBase):
             self.mathtext_parser.parse(s, 72, prop)
         svg_glyphs = svg_elements.svg_glyphs
         svg_rects = svg_elements.svg_rects
-        color = rgb2hex(gc.get_rgb()[:3])
+        color = rgb2hex(gc.get_rgb())
         write = self._svgwriter.write
 
         style = "fill: %s" % color
@@ -848,7 +860,7 @@ class FigureCanvasSVG(FigureCanvasBase):
         if is_string_like(filename):
             fh_to_close = svgwriter = codecs.open(filename, 'w', 'utf-8')
         elif is_writable_file_like(filename):
-            svgwriter = codecs.EncodedFile(filename, 'utf-8')
+            svgwriter = codecs.getwriter('utf-8')(filename)
             fh_to_close = None
         else:
             raise ValueError("filename must be a path or a file-like object")
@@ -857,10 +869,10 @@ class FigureCanvasSVG(FigureCanvasBase):
     def print_svgz(self, filename, *args, **kwargs):
         if is_string_like(filename):
             gzipwriter = gzip.GzipFile(filename, 'w')
-            fh_to_close = svgwriter = codecs.EncodedFile(gzipwriter, 'utf-8')
+            fh_to_close = svgwriter = codecs.getwriter('utf-8')(gzipwriter)
         elif is_writable_file_like(filename):
             fh_to_close = gzipwriter = gzip.GzipFile(fileobj=filename, mode='w')
-            svgwriter = codecs.EncodedFile(gzipwriter, 'utf-8')
+            svgwriter = codecs.getwriter('utf-8')(gzipwriter)
         else:
             raise ValueError("filename must be a path or a file-like object")
         return self._print_svg(filename, svgwriter, fh_to_close)
