@@ -18,9 +18,10 @@ from matplotlib.cbook import is_string_like
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase
 from matplotlib.backend_bases import FigureManagerBase, FigureCanvasBase
 from matplotlib.backend_bases import NavigationToolbar2, cursors, TimerBase
+from matplotlib.backend_bases import ShowBase
+from matplotlib._pylab_helpers import Gcf
 
 from matplotlib.figure import Figure
-from matplotlib._pylab_helpers import Gcf
 
 from matplotlib.widgets import SubplotTool
 
@@ -63,15 +64,11 @@ def draw_if_interactive():
         if figManager is not None:
             figManager.show()
 
+class Show(ShowBase):
+    def mainloop(self):
+        Tk.mainloop()
 
-def show():
-    """
-    Show all figures.
-
-    """
-    for manager in Gcf.get_all_fig_managers():
-        manager.show()
-    Tk.mainloop()
+show = Show()
 
 def new_figure_manager(num, *args, **kwargs):
     """
@@ -315,8 +312,8 @@ class FigureCanvasTkAgg(FigureCanvasAgg):
         x = event.x
         y = self.figure.bbox.height - event.y
         num = getattr(event, 'num', None)
-        if   num==4: step = -1
-        elif num==5: step = +1
+        if   num==4: step = +1
+        elif num==5: step = -1
         else:        step =  0
 
         FigureCanvasBase.scroll_event(self, x, y, step, guiEvent=event)
