@@ -18,12 +18,14 @@ from __future__ import division
 
 """
 
-cvs_id = '$Id: backend_wx.py 8442 2010-06-20 01:34:30Z efiring $'
+cvs_id = '$Id: backend_wx.py 8767 2010-11-01 13:04:29Z mdboom $'
 
 
 import sys, os, os.path, math, StringIO, weakref, warnings
 import numpy as np
 
+
+
 # Debugging settings here...
 # Debug level set here. If the debug level is less than 5, information
 # messages (progressively more info for lower value) are printed. In addition,
@@ -117,6 +119,8 @@ from matplotlib import verbose
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase,\
      FigureCanvasBase, FigureManagerBase, NavigationToolbar2, \
      cursors, TimerBase
+from matplotlib.backend_bases import ShowBase
+
 from matplotlib._pylab_helpers import Gcf
 from matplotlib.artist import Artist
 from matplotlib.cbook import exception_to_str, is_string_like, is_writable_file_like
@@ -771,6 +775,7 @@ class FigureCanvasWx(FigureCanvasBase, wx.Panel):
         wx.TheClipboard.Open()
         wx.TheClipboard.SetData(bmp_obj)
         wx.TheClipboard.Close()
+        wx.TheClipboard.Flush()
 
     def Printer_Init(self):
         """
@@ -1394,23 +1399,15 @@ def draw_if_interactive():
         if figManager is not None:
             figManager.canvas.draw_idle()
 
-def show():
-    """
-    Show all the figures and enter the wx main loop.
-    This should be the last line of your script.
-    """
-    DEBUG_MSG("show()", 3, None)
-
-    for figwin in Gcf.get_all_fig_managers():
-        figwin.frame.Show()
-
-    needmain = not wx.App.IsMainLoopRunning()
-    if  needmain and len(Gcf.get_all_fig_managers())>0:
-        wxapp = wx.GetApp()
-        if wxapp is not None:
-            wxapp.MainLoop()
-            # start the wxPython gui event if there is not already one running
+class Show(ShowBase):
+    def mainloop(self):
+        needmain = not wx.App.IsMainLoopRunning()
+        if needmain:
+            wxapp = wx.GetApp()
+            if wxapp is not None:
+                wxapp.MainLoop()
 
+show = Show()
 
 def new_figure_manager(num, *args, **kwargs):
     """
@@ -1555,6 +1552,8 @@ class FigureManagerWx(FigureManagerBase):
         # attach a show method to the figure
         self.canvas.figure.show = showfig
 
+    def show(self):
+        self.frame.Show()
 
     def destroy(self, *args):
         DEBUG_MSG("destroy()", 1, self)
