@@ -26,8 +26,11 @@ major, minor1, minor2, s, tmp = sys.version_info
 # an encoding instead of a valid locale name.  Another
 # pathological case that has been reported is an empty string.
 
+# On some systems, getpreferredencoding sets the locale, which has
+# side effects.  Passing False eliminates those side effects.
+
 try:
-    preferredencoding = locale.getpreferredencoding().strip()
+    preferredencoding = locale.getpreferredencoding(False).strip()
     if not preferredencoding:
         preferredencoding = None
 except (ValueError, ImportError, AttributeError):
@@ -649,9 +652,20 @@ def get_sample_data(fname, asfileobj=True):
       svn co https://matplotlib.svn.sourceforge.net/svnroot/matplotlib/trunk/sample_data
 
     and svn add the data file you want to support.  This is primarily
-    intended for use in mpl examples that need custom data
+    intended for use in mpl examples that need custom data.
+
+    To bypass all downloading, set the rc parameter examples.download to False
+    and examples.directory to the directory where we should look.
     """
 
+    if not matplotlib.rcParams['examples.download']:
+        directory = matplotlib.rcParams['examples.directory']
+        f = os.path.join(directory, fname)
+        if asfileobj:
+            return open(f, 'rb')
+        else:
+            return f
+
     myserver = get_sample_data.myserver
     if myserver is None:
         configdir = matplotlib.get_configdir()
