@@ -500,6 +500,12 @@ class Collection(artist.Artist, cm.ScalarMappable):
         self._linestyles = other._linestyles
         self._pickradius = other._pickradius
 
+        # update_from for scalarmappable
+        self._A = other._A
+        self.norm = other.norm
+        self.cmap = other.cmap
+        # self.update_dict = other.update_dict # do we need to copy this? -JJL
+
 # these are not available for the object inspector until after the
 # class is built so we define an initial set here for the init
 # function and they will be overridden after object defn
@@ -1034,13 +1040,14 @@ class PatchCollection(Collection):
 
         if match_original:
             def determine_facecolor(patch):
-                if patch.fill:
+                if patch.get_fill():
                     return patch.get_facecolor()
                 return [0, 0, 0, 0]
 
             facecolors   = [determine_facecolor(p) for p in patches]
             edgecolors   = [p.get_edgecolor() for p in patches]
             linewidths   = [p.get_linewidth() for p in patches]
+            linestyles   = [p.get_linestyle() for p in patches]
             antialiaseds = [p.get_antialiased() for p in patches]
 
             Collection.__init__(
@@ -1048,7 +1055,7 @@ class PatchCollection(Collection):
                 edgecolors=edgecolors,
                 facecolors=facecolors,
                 linewidths=linewidths,
-                linestyles='solid',
+                linestyles=linestyles,
                 antialiaseds = antialiaseds)
         else:
             Collection.__init__(self, **kwargs)
@@ -1228,6 +1235,7 @@ class QuadMesh(Collection):
 
         gc = renderer.new_gc()
         self._set_gc_clip(gc)
+        gc.set_linewidth(self.get_linewidth()[0])
 
         if self._shading == 'gouraud':
             triangles, colors = self.convert_mesh_to_triangles(
