@@ -18,11 +18,13 @@ and :class:`Colorbar`; the :func:`~matplotlib.pyplot.colorbar` function
 is a thin wrapper over :meth:`~matplotlib.figure.Figure.colorbar`.
 
 '''
+import warnings
 
 import numpy as np
 import matplotlib as mpl
 import matplotlib.colors as colors
 import matplotlib.cm as cm
+from matplotlib import docstring
 import matplotlib.ticker as ticker
 import matplotlib.cbook as cbook
 import matplotlib.lines as lines
@@ -150,6 +152,7 @@ returns:
 
 ''' % (make_axes_kw_doc, colormap_kw_doc)
 
+docstring.interpd.update(colorbar_doc=colorbar_doc)
 
 
 class ColorbarBase(cm.ScalarMappable):
@@ -157,8 +160,9 @@ class ColorbarBase(cm.ScalarMappable):
     Draw a colorbar in an existing axes.
 
     This is a base class for the :class:`Colorbar` class, which is the
-    basis for the :func:`~matplotlib.pyplot.colorbar` method and pylab
-    function.
+    basis for the :func:`~matplotlib.pyplot.colorbar` function and the
+    :meth:`~matplotlib.figure.Figure.colorbar` method, which are the
+    usual ways of creating a colorbar.
 
     It is also useful by itself for showing a colormap.  If the *cmap*
     kwarg is given but *boundaries* and *values* are left as None,
@@ -193,7 +197,7 @@ class ColorbarBase(cm.ScalarMappable):
 
     def __init__(self, ax, cmap=None,
                            norm=None,
-                           alpha=1.0,
+                           alpha=None,
                            values=None,
                            boundaries=None,
                            orientation='vertical',
@@ -205,6 +209,7 @@ class ColorbarBase(cm.ScalarMappable):
                            filled=True,
                            ):
         self.ax = ax
+        self._patch_ax()
         if cmap is None: cmap = cm.get_cmap()
         if norm is None: norm = colors.Normalize()
         self.alpha = alpha
@@ -219,6 +224,8 @@ class ColorbarBase(cm.ScalarMappable):
         self.filled = filled
         self.solids = None
         self.lines = None
+        self.outline = None
+        self.patch = None
         self.dividers = None
         self.set_label('')
         if cbook.iterable(ticks):
@@ -235,8 +242,16 @@ class ColorbarBase(cm.ScalarMappable):
         else:
             self.formatter = format  # Assume it is a Formatter
         # The rest is in a method so we can recalculate when clim changes.
+        self.config_axis()
         self.draw_all()
 
+    def _patch_ax(self):
+        def _warn(*args, **kw):
+            warnings.warn("Use the colorbar set_ticks() method instead.")
+
+        self.ax.set_xticks = _warn
+        self.ax.set_yticks = _warn
+
     def draw_all(self):
         '''
         Calculate any free parameters based on the current cmap and norm,
@@ -249,8 +264,62 @@ class ColorbarBase(cm.ScalarMappable):
         self._config_axes(X, Y)
         if self.filled:
             self._add_solids(X, Y, C)
+
+    def config_axis(self):
+        ax = self.ax
+        if self.orientation == 'vertical':
+            ax.xaxis.set_ticks([])
+            ax.yaxis.set_label_position('right')
+            ax.yaxis.set_ticks_position('right')
+        else:
+            ax.yaxis.set_ticks([])
+            ax.xaxis.set_label_position('bottom')
+
         self._set_label()
 
+    def update_ticks(self):
+        """
+        Force the update of the ticks and ticklabels. This must be
+        called whenever the tick locator and/or tick formatter changes.
+        """
+        ax = self.ax
+        ticks, ticklabels, offset_string = self._ticker()
+        if self.orientation == 'vertical':
+            ax.yaxis.set_ticks(ticks)
+            ax.set_yticklabels(ticklabels)
+            ax.yaxis.get_major_formatter().set_offset_string(offset_string)
+
+        else:
+            ax.xaxis.set_ticks(ticks)
+            ax.set_xticklabels(ticklabels)
+            ax.xaxis.get_major_formatter().set_offset_string(offset_string)
+
+    def set_ticks(self, ticks, update_ticks=True):
+        """
+        set tick locations. Tick locations are updated immediately unless update_ticks is
+        *False*. To manually update the ticks, call *update_ticks* method explicitly.
+        """
+        if cbook.iterable(ticks):
+            self.locator = ticker.FixedLocator(ticks, nbins=len(ticks))
+        else:
+            self.locator = ticks
+
+        if update_ticks:
+            self.update_ticks()
+
+    def set_ticklabels(self, ticklabels, update_ticks=True):
+        """
+        set tick labels. Tick labels are updated immediately unless update_ticks is
+        *False*. To manually update the ticks, call *update_ticks* method explicitly.
+        """
+        if isinstance(self.locator, ticker.FixedLocator):
+            self.formatter = ticker.FixedFormatter(ticklabels)
+            if update_ticks:
+                self.update_ticks()
+        else:
+            warnings.warn("set_ticks() must have been called.")
+
+
     def _config_axes(self, X, Y):
         '''
         Make an axes patch and outline.
@@ -262,32 +331,24 @@ class ColorbarBase(cm.ScalarMappable):
         ax.update_datalim(xy)
         ax.set_xlim(*ax.dataLim.intervalx)
         ax.set_ylim(*ax.dataLim.intervaly)
+        if self.outline is not None:
+            self.outline.remove()
         self.outline = lines.Line2D(xy[:, 0], xy[:, 1], color=mpl.rcParams['axes.edgecolor'],
                                     linewidth=mpl.rcParams['axes.linewidth'])
         ax.add_artist(self.outline)
         self.outline.set_clip_box(None)
         self.outline.set_clip_path(None)
         c = mpl.rcParams['axes.facecolor']
+        if self.patch is not None:
+            self.patch.remove()
         self.patch = patches.Polygon(xy, edgecolor=c,
                  facecolor=c,
                  linewidth=0.01,
                  zorder=-1)
         ax.add_artist(self.patch)
-        ticks, ticklabels, offset_string = self._ticker()
-        if self.orientation == 'vertical':
-            ax.set_xticks([])
-            ax.yaxis.set_label_position('right')
-            ax.yaxis.set_ticks_position('right')
-            ax.set_yticks(ticks)
-            ax.set_yticklabels(ticklabels)
-            ax.yaxis.get_major_formatter().set_offset_string(offset_string)
 
-        else:
-            ax.set_yticks([])
-            ax.xaxis.set_label_position('bottom')
-            ax.set_xticks(ticks)
-            ax.set_xticklabels(ticklabels)
-            ax.xaxis.get_major_formatter().set_offset_string(offset_string)
+        self.update_ticks()
+
 
     def _set_label(self):
         if self.orientation == 'vertical':
@@ -336,22 +397,27 @@ class ColorbarBase(cm.ScalarMappable):
         Draw the colors using :meth:`~matplotlib.axes.Axes.pcolor`;
         optionally add separators.
         '''
-        ## Change to pcolorfast after fixing bugs in some backends...
         if self.orientation == 'vertical':
             args = (X, Y, C)
         else:
             args = (np.transpose(Y), np.transpose(X), np.transpose(C))
         kw = {'cmap':self.cmap, 'norm':self.norm,
-                    'shading':'flat', 'alpha':self.alpha}
+                    'alpha':self.alpha,}
         # Save, set, and restore hold state to keep pcolor from
         # clearing the axes. Ordinarily this will not be needed,
         # since the axes object should already have hold set.
         _hold = self.ax.ishold()
         self.ax.hold(True)
-        col = self.ax.pcolor(*args, **kw)
+        col = self.ax.pcolormesh(*args, **kw)
         self.ax.hold(_hold)
         #self.add_observer(col) # We should observe, not be observed...
+
+        if self.solids is not None:
+            self.solids.remove()
         self.solids = col
+        if self.dividers is not None:
+            self.dividers.remove()
+            self.dividers = None
         if self.drawedges:
             self.dividers = collections.LineCollection(self._edges(X,Y),
                               colors=(mpl.rcParams['axes.edgecolor'],),
@@ -374,6 +440,9 @@ class ColorbarBase(cm.ScalarMappable):
         else:
             xy = [zip(Y[i], X[i]) for i in range(N)]
         col = collections.LineCollection(xy, linewidths=linewidths)
+
+        if self.lines:
+            self.lines.remove()
         self.lines = col
         col.set_color(colors)
         self.ax.add_collection(col)
@@ -412,6 +481,10 @@ class ColorbarBase(cm.ScalarMappable):
         locator.set_data_interval(*intv)
         formatter.set_view_interval(*intv)
         formatter.set_data_interval(*intv)
+
+        # the dummy axis is expecting a minpos
+        locator.axis.get_minpos = lambda : intv[0]
+        formatter.axis.get_minpos = lambda : intv[0]
         b = np.array(locator())
         b, ticks = self._locate(b)
         formatter.set_locs(b)
@@ -618,6 +691,17 @@ class ColorbarBase(cm.ScalarMappable):
         self.alpha = alpha
 
 class Colorbar(ColorbarBase):
+    """
+    This class connects a :class:`ColorbarBase` to a
+    :class:`~matplotlib.cm.ScalarMappable` such as a
+    :class:`~matplotlib.image.AxesImage` generated via
+    :meth:`~matplotlib.axes.Axes.imshow`.
+
+    It is not intended to be instantiated directly; instead,
+    use :meth:`~matplotlib.figure.Figure.colorbar` or
+    :func:`~matplotlib.pyplot.colorbar` to make your colorbar.
+
+    """
     def __init__(self, ax, mappable, **kw):
         mappable.autoscale_None() # Ensure mappable.norm.vmin, vmax
                              # are set when colorbar is called,
@@ -666,21 +750,44 @@ class Colorbar(ColorbarBase):
         #print 'tlinewidths:', tlinewidths
         ColorbarBase.add_lines(self, CS.levels, tcolors, tlinewidths)
 
+    def update_normal(self, mappable):
+        '''
+        update solid, lines, etc. Unlike update_bruteforce, it does
+        not clear the axes.  This is meant to be called when the image
+        or contour plot to which this colorbar belongs is changed.
+        '''
+        self.draw_all()
+        if isinstance(self.mappable, contour.ContourSet):
+            CS = self.mappable
+            if not CS.filled:
+                self.add_lines(CS)
+
+
     def update_bruteforce(self, mappable):
         '''
-        Manually change any contour line colors.  This is called
-        when the image or contour plot to which this colorbar belongs
-        is changed.
+        Destroy and rebuild the colorbar.  This is
+        intended to become obsolete, and will probably be
+        deprecated and then removed.  It is not called when
+        the pyplot.colorbar function or the Figure.colorbar
+        method are used to create the colorbar.
+
         '''
         # We are using an ugly brute-force method: clearing and
         # redrawing the whole thing.  The problem is that if any
         # properties have been changed by methods other than the
         # colorbar methods, those changes will be lost.
         self.ax.cla()
+        # clearing the axes will delete outline, patch, solids, and lines:
+        self.outline = None
+        self.patch = None
+        self.solids = None
+        self.lines = None
+        self.dividers = None
+        self.set_alpha(mappable.get_alpha())
+        self.cmap = mappable.cmap
+        self.norm = mappable.norm
+        self.config_axis()
         self.draw_all()
-        #if self.vmin != self.norm.vmin or self.vmax != self.norm.vmax:
-        #    self.ax.cla()
-        #    self.draw_all()
         if isinstance(self.mappable, contour.ContourSet):
             CS = self.mappable
             if not CS.filled:
@@ -693,7 +800,25 @@ class Colorbar(ColorbarBase):
         # be recalculating everything if there was a simple alpha
         # change.
 
+@docstring.Substitution(make_axes_kw_doc)
 def make_axes(parent, **kw):
+    '''
+    Resize and reposition a parent axes, and return a child
+    axes suitable for a colorbar::
+
+        cax, kw = make_axes(parent, **kw)
+
+    Keyword arguments may include the following (with defaults):
+
+        *orientation*
+            'vertical'  or 'horizontal'
+
+    %s
+
+    All but the first of these are stripped from the input kw set.
+
+    Returns (cax, kw), the child axes and the reduced kw dictionary.
+    '''
     orientation = kw.setdefault('orientation', 'vertical')
     fraction = kw.pop('fraction', 0.15)
     shrink = kw.pop('shrink', 1.0)
@@ -720,22 +845,3 @@ def make_axes(parent, **kw):
     cax = fig.add_axes(pbcb)
     cax.set_aspect(aspect, anchor=anchor, adjustable='box')
     return cax, kw
-make_axes.__doc__ ='''
-    Resize and reposition a parent axes, and return a child
-    axes suitable for a colorbar::
-
-        cax, kw = make_axes(parent, **kw)
-
-    Keyword arguments may include the following (with defaults):
-
-        *orientation*
-            'vertical'  or 'horizontal'
-
-    %s
-
-    All but the first of these are stripped from the input kw set.
-
-    Returns (cax, kw), the child axes and the reduced kw dictionary.
-    '''  % make_axes_kw_doc
-
-
