@@ -4,7 +4,7 @@ financial data.   User contributions welcome!
 
 """
 #from __future__ import division
-import os, time, warnings
+import os, warnings
 from urllib2 import urlopen
 
 try:
@@ -17,7 +17,7 @@ import numpy as np
 
 from matplotlib import verbose, get_configdir
 from matplotlib.dates import date2num
-from matplotlib.cbook import iterable, is_string_like
+from matplotlib.cbook import iterable
 from matplotlib.collections import LineCollection, PolyCollection
 from matplotlib.colors import colorConverter
 from matplotlib.lines import Line2D, TICKLEFT, TICKRIGHT
@@ -38,7 +38,7 @@ stock_dt = np.dtype([('date', object),
                      ('close', np.float),
                      ('high', np.float),
                      ('low', np.float),
-                     ('volume', np.int),
+                     ('volume', np.float),
                      ('aclose', np.float)])
 
 
@@ -47,12 +47,16 @@ def parse_yahoo_historical(fh, adjusted=True, asobject=False):
     Parse the historical data in file handle fh from yahoo finance.
 
     *adjusted*
-      If True (default) replace open, close, high, low, and volume with
-      their adjusted values.
-      The adjustment is by a scale factor, S = adjusted_close/close.
-      Adjusted volume is actual volume divided by S;
-      Adjusted prices are actual prices multiplied by S.  Hence,
-      the product of price and volume is unchanged by the adjustment.
+      If True (default) replace open, close, high, and low prices with
+      their adjusted values. The adjustment is by a scale factor, S =
+      adjusted_close/close. Adjusted prices are actual prices
+      multiplied by S.
+
+      Volume is not adjusted as it is already backward split adjusted
+      by Yahoo. If you want to compute dollars traded, multiply volume
+      by the adjusted close, regardless of whether you choose adjusted
+      = True|False.
+
 
     *asobject*
       If False (default for compatibility with earlier versions)
@@ -97,7 +101,7 @@ def parse_yahoo_historical(fh, adjusted=True, asobject=False):
         dt = datetime.date(*[int(val) for val in datestr.split('-')])
         dnum = date2num(dt)
         open, high, low, close =  [float(val) for val in vals[1:5]]
-        volume = int(vals[5])
+        volume = float(vals[5])
         aclose = float(vals[6])
 
         results.append((dt, dt.year, dt.month, dt.day,
@@ -218,7 +222,7 @@ def quotes_historical_yahoo(ticker, date1, date2, asobject=False,
         if len(ret) == 0:
             return None
     except IOError, exc:
-        warnings.warn('urlopen() failure\n' + url + '\n' + exc.strerror[1])
+        warnings.warn('fh failure\n%s'%(exc.strerror[1]))
         return None
 
     return ret
