@@ -346,7 +346,7 @@ class HammerAxes(GeoAxes):
             cos_latitude = np.cos(latitude)
             sqrt2 = np.sqrt(2.0)
 
-            alpha = 1.0 + cos_latitude * np.cos(half_long)
+            alpha = np.sqrt(1.0 + cos_latitude * np.cos(half_long))
             x = (2.0 * sqrt2) * (cos_latitude * np.sin(half_long)) / alpha
             y = (sqrt2 * np.sin(latitude)) / alpha
             return np.concatenate((x, y), 1)
