@@ -13,7 +13,8 @@ from matplotlib.patches import Circle
 from matplotlib.path import Path
 from matplotlib.ticker import Formatter, Locator, FormatStrFormatter
 from matplotlib.transforms import Affine2D, Affine2DBase, Bbox, \
-    BboxTransformTo, IdentityTransform, Transform, TransformWrapper
+    BboxTransformTo, IdentityTransform, Transform, TransformWrapper, \
+    ScaledTranslation, blended_transform_factory, BboxTransformToMaxOnly
 import matplotlib.spines as mspines
 
 class PolarAxes(Axes):
@@ -40,16 +41,16 @@ class PolarAxes(Axes):
             self._axis = axis
 
         def transform(self, tr):
-            xy   = np.zeros(tr.shape, np.float_)
+            xy = np.empty(tr.shape, np.float_)
             if self._axis is not None:
                 rmin = self._axis.viewLim.ymin
             else:
                 rmin = 0
 
-            t    = tr[:, 0:1]
-            r    = tr[:, 1:2]
-            x    = xy[:, 0:1]
-            y    = xy[:, 1:2]
+            t = tr[:, 0:1]
+            r = tr[:, 1:2]
+            x = xy[:, 0:1]
+            y = xy[:, 1:2]
 
             if rmin != 0:
                 r = r - rmin
@@ -87,10 +88,10 @@ class PolarAxes(Axes):
         that maximum radius rests on the edge of the axes circle.
         """
         def __init__(self, scale_transform, limits):
-            u"""
+            """
             *limits* is the view limit of the data.  The only part of
             its bounds that is used is ymax (for the radius maximum).
-            The theta range is always fixed to (0, 2\u03c0).
+            The theta range is always fixed to (0, 2pi).
             """
             Affine2DBase.__init__(self)
             self._scale_transform = scale_transform
@@ -140,10 +141,9 @@ class PolarAxes(Axes):
         inverted.__doc__ = Transform.inverted.__doc__
 
     class ThetaFormatter(Formatter):
-        u"""
-        Used to format the *theta* tick labels.  Converts the
-        native unit of radians into degrees and adds a degree symbol
-        (\u00b0).
+        """
+        Used to format the *theta* tick labels.  Converts the native
+        unit of radians into degrees and adds a degree symbol.
         """
         def __call__(self, x, pos=None):
             # \u00b0 : degree symbol
@@ -287,13 +287,19 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
             Affine2D().scale(np.pi * 2.0, 1.0) +
             self.transData)
         # The r-axis labels are put at an angle and padded in the r-direction
-        self._r_label1_position = Affine2D().translate(22.5, self._rpad)
+        self._r_label1_position = ScaledTranslation(
+            22.5, self._rpad,
+            blended_transform_factory(
+                Affine2D(), BboxTransformToMaxOnly(self.viewLim)))
         self._yaxis_text1_transform = (
             self._r_label1_position +
             Affine2D().scale(1.0 / 360.0, 1.0) +
             self._yaxis_transform
             )
-        self._r_label2_position = Affine2D().translate(22.5, self._rpad)
+        self._r_label2_position = ScaledTranslation(
+            22.5, -self._rpad,
+            blended_transform_factory(
+                Affine2D(), BboxTransformToMaxOnly(self.viewLim)))
         self._yaxis_text2_transform = (
             self._r_label2_position +
             Affine2D().scale(1.0 / 360.0, 1.0) +
@@ -435,9 +441,10 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
             angle = self._r_label1_position.to_values()[4]
         if rpad is not None:
             self._rpad = rpad
-        rmax = self.get_rmax()
-        self._r_label1_position.clear().translate(angle, self._rpad * rmax)
-        self._r_label2_position.clear().translate(angle, -self._rpad * rmax)
+        self._r_label1_position._t = (angle, self._rpad)
+        self._r_label1_position.invalidate()
+        self._r_label2_position._t = (angle, -self._rpad)
+        self._r_label2_position.invalidate()
         for t in self.yaxis.get_ticklabels():
             t.update(kwargs)
         return self.yaxis.get_gridlines(), self.yaxis.get_ticklabels()
@@ -516,11 +523,11 @@ cbook.simple_linear_interpolation on the data before passing to matplotlib.""")
                 dt = dt0 * -1.0
             dt = (dt / np.pi) * 180.0
 
-            rpad = self._r_label1_position.to_values()[5]
-            self._r_label1_position.clear().translate(
-                p.r_label_angle - dt, rpad)
-            self._r_label2_position.clear().translate(
-                p.r_label_angle - dt, -rpad)
+            rpad = self._rpad
+            self._r_label1_position._t = (p.r_label_angle - dt, rpad)
+            self._r_label1_position.invalidate()
+            self._r_label2_position._t = (p.r_label_angle - dt, -rpad)
+            self._r_label2_position.invalidate()
 
         elif p.mode == 'zoom':
             startt, startr = p.trans_inverse.transform_point((p.x, p.y))
