@@ -143,6 +143,9 @@ class Text(Artist):
     Handle storing and drawing of text in window or data coordinates.
     """
     zorder = 3
+
+    cached = maxdict(50)
+
     def __str__(self):
         return "Text(%g,%g,%s)"%(self._y,self._y,repr(self._text))
 
@@ -168,7 +171,6 @@ class Text(Artist):
         """
 
         Artist.__init__(self)
-        self.cached = maxdict(5)
         self._x, self._y = x, y
 
         if color is None: color = rcParams['text.color']
@@ -541,8 +543,7 @@ class Text(Artist):
         gc.set_foreground(self.get_color())
         gc.set_alpha(self.get_alpha())
         gc.set_url(self._url)
-        if self.get_clip_on():
-            gc.set_clip_rectangle(self.clipbox)
+        self._set_gc_clip(gc)
 
         if self._bbox:
             bbox_artist(self, renderer, self._bbox)
@@ -552,6 +553,9 @@ class Text(Artist):
 
         if rcParams['text.usetex']:
             for line, wh, x, y in info:
+                if not np.isfinite(x) or not np.isfinite(y):
+                    continue
+
                 x = x + posx
                 y = y + posy
                 if renderer.flipy():
@@ -567,6 +571,9 @@ class Text(Artist):
                                       self._fontproperties, angle)
         else:
             for line, wh, x, y in info:
+                if not np.isfinite(x) or not np.isfinite(y):
+                    continue
+
                 x = x + posx
                 y = y + posy
                 if renderer.flipy():
@@ -975,6 +982,8 @@ class Text(Artist):
         # Did we find an even number of non-escaped dollar signs?
         # If so, treat is as math text.
         if rcParams['text.usetex']:
+            if s == ' ':
+                s = r'\ '
             return s, 'TeX'
 
         if cbook.is_math_text(s):
@@ -1434,6 +1443,9 @@ class _AnnotationBase(object):
             y = float(self.convert_yunits(y))
 
 
+        if s in ['axes points', 'axes pixel', 'figure points', 'figure pixel']:
+                 return self._get_xy_legacy(renderer, x, y, s)
+
         tr = self._get_xy_transform(renderer, s)
         x1, y1 = tr.transform_point((x, y))
         return x1, y1
