@@ -546,7 +546,7 @@ class LogFormatter(Formatter):
         sign = np.sign(x)
         # only label the decades
         fx = math.log(abs(x))/math.log(b)
-        isDecade = self.is_decade(fx)
+        isDecade = is_decade(fx)
         if not isDecade and self.labelOnlyBase: s = ''
         elif x>10000: s= '%1.0e'%x
         elif x<1: s =  '%1.0e'%x
@@ -567,15 +567,6 @@ class LogFormatter(Formatter):
         'return a short formatted string representation of a number'
         return '%-12g'%value
 
-    def is_decade(self, x):
-        n = self.nearest_long(x)
-        return abs(x-n)<1e-10
-
-    def nearest_long(self, x):
-        if x == 0: return 0L
-        elif x > 0: return long(x+0.5)
-        else: return long(x-0.5)
-
     def pprint_val(self, x, d):
         #if the number is not too big and it's an int, format it as an
         #int
@@ -617,7 +608,7 @@ class LogFormatterExponent(LogFormatter):
         sign = np.sign(x)
         # only label the decades
         fx = math.log(abs(x))/math.log(b)
-        isDecade = self.is_decade(fx)
+        isDecade = is_close_to_int(fx)
         if not isDecade and self.labelOnlyBase: s = ''
         #if 0: pass
         elif fx>10000: s= '%1.0e'%fx
@@ -639,14 +630,17 @@ class LogFormatterMathtext(LogFormatter):
     def __call__(self, x, pos=None):
         'Return the format for tick val *x* at position *pos*'
         b = self._base
+        usetex = rcParams['text.usetex']
+
         # only label the decades
         if x == 0:
-            return '$0$'
+            if usetex:
+                return '$0$'
+            else:
+                return '$\mathdefault{0}$'
         sign = np.sign(x)
         fx = math.log(abs(x))/math.log(b)
-        isDecade = self.is_decade(fx)
-
-        usetex = rcParams['text.usetex']
+        isDecade = is_close_to_int(fx)
 
         if sign == -1:
             sign_string = '-'
@@ -661,10 +655,10 @@ class LogFormatterMathtext(LogFormatter):
                 s = '$\mathdefault{%s%d^{%.2f}}$'% (sign_string, b, fx)
         else:
             if usetex:
-                s = r'$%s%d^{%d}$'% (sign_string, b, self.nearest_long(fx))
+                s = r'$%s%d^{%d}$'% (sign_string, b, nearest_long(fx))
             else:
                 s = r'$\mathdefault{%s%d^{%d}}$'% (sign_string, b,
-                                                   self.nearest_long(fx))
+                                                   nearest_long(fx))
 
         return s
 
@@ -1190,11 +1184,23 @@ def decade_up(x, base=10):
     lx = math.ceil(math.log(x)/math.log(base))
     return base**lx
 
-def is_decade(x,base=10):
+def nearest_long(x):
+    if x == 0: return 0L
+    elif x > 0: return long(x+0.5)
+    else: return long(x-0.5)
+
+def is_decade(x, base=10):
+    if not np.isfinite(x):
+        return False
     if x == 0.0:
         return True
-    lx = math.log(x)/math.log(base)
-    return lx==int(lx)
+    lx = math.log(abs(x))/math.log(base)
+    return is_close_to_int(lx)
+
+def is_close_to_int(x):
+    if not np.isfinite(x):
+        return False
+    return abs(x - nearest_long(x)) < 1e-10
 
 class LogLocator(Locator):
     """
@@ -1212,7 +1218,7 @@ class LogLocator(Locator):
 
     def base(self,base):
         """
-        set the base of the log scaling (major tick every base**i, i interger)
+        set the base of the log scaling (major tick every base**i, i integer)
         """
         self._base=base+0.0
 
@@ -1244,7 +1250,7 @@ class LogLocator(Locator):
 
         if vmin <= 0.0:
             vmin = self.axis.get_minpos()
-            if vmin <= 0.0:
+            if vmin <= 0.0 or not np.isfinite(vmin):
                 raise ValueError(
                     "Data has no positive values, and therefore can not be log-scaled.")
 
@@ -1292,7 +1298,7 @@ class LogLocator(Locator):
 
         minpos = self.axis.get_minpos()
 
-        if minpos<=0:
+        if minpos<=0 or not np.isfinite(minpos):
             raise ValueError(
                 "Data has no positive values, and therefore can not be log-scaled.")
 
