@@ -106,6 +106,7 @@ class Button(Widget):
 
 
         ax.figure.canvas.mpl_connect('button_press_event', self._click)
+        ax.figure.canvas.mpl_connect('button_release_event', self._release)
         ax.figure.canvas.mpl_connect('motion_notify_event', self._motion)
         ax.set_navigate(False)
         ax.set_axis_bgcolor(color)
@@ -117,8 +118,21 @@ class Button(Widget):
         self._lastcolor = color
 
     def _click(self, event):
-        if event.inaxes != self.ax: return
-        if not self.eventson: return
+        if event.inaxes != self.ax:
+            return
+        if not self.eventson:
+            return
+        if event.canvas.mouse_grabber != self.ax:
+            event.canvas.grab_mouse(self.ax)
+
+    def _release(self, event):
+        if event.canvas.mouse_grabber != self.ax:
+            return
+        event.canvas.release_mouse(self.ax)
+        if not self.eventson:
+            return
+        if event.inaxes != self.ax:
+            return
         for cid, func in self.observers.items():
             func(event)
 
@@ -209,6 +223,7 @@ class Slider(Widget):
         ax.set_navigate(False)
 
         ax.figure.canvas.mpl_connect('button_press_event', self._update)
+        ax.figure.canvas.mpl_connect('button_release_event', self._update)
         if dragging:
             ax.figure.canvas.mpl_connect('motion_notify_event', self._update)
         self.label = ax.text(-0.02, 0.5, label, transform=ax.transAxes,
@@ -227,14 +242,35 @@ class Slider(Widget):
         self.closedmax = closedmax
         self.slidermin = slidermin
         self.slidermax = slidermax
+        self.drag_active  = False
 
     def _update(self, event):
         'update the slider position'
-        if event.button !=1: return
-        if event.inaxes != self.ax: return
+        if event.button != 1:
+            return
+
+        if event.name == 'button_press_event' and event.inaxes == self.ax:
+            self.drag_active = True
+            event.canvas.grab_mouse(self.ax)
+
+        if not self.drag_active:
+            return
+
+        elif ((event.name == 'button_release_event')
+             or (event.name == 'button_press_event' and event.inaxes != self.ax)):
+            self.drag_active = False
+            event.canvas.release_mouse(self.ax)
+            return
+
         val = event.xdata
-        if not self.closedmin and val<=self.valmin: return
-        if not self.closedmax and val>=self.valmax: return
+        if val <= self.valmin:
+            if not self.closedmin:
+                return
+            val = self.valmin
+        elif val >= self.valmax:
+            if not self.closedmax:
+                return
+            val = self.valmax
 
         if self.slidermin is not None:
             if val<=self.slidermin.val: return
@@ -669,6 +705,8 @@ class Cursor:
         self.vertOn = True
         self.useblit = useblit
 
+        if useblit:
+            lineprops['animated'] = True
         self.lineh = ax.axhline(ax.get_ybound()[0], visible=False, **lineprops)
         self.linev = ax.axvline(ax.get_xbound()[0], visible=False, **lineprops)
 
@@ -741,10 +779,14 @@ class MultiCursor:
 
     """
     def __init__(self, canvas, axes, useblit=True, **lineprops):
+
         self.canvas = canvas
         self.axes = axes
         xmin, xmax = axes[-1].get_xlim()
         xmid = 0.5*(xmin+xmax)
+        if useblit:
+            lineprops['animated'] = True
+
         self.lines = [ax.axvline(xmid, visible=False, **lineprops) for ax in axes]
 
         self.visible = True
@@ -864,9 +906,9 @@ class SpanSelector:
 
             self.cids.append(self.canvas.mpl_connect('motion_notify_event', self.onmove))
             self.cids.append(self.canvas.mpl_connect('button_press_event', self.press))
-	    self.cids.append(self.canvas.mpl_connect('button_release_event', self.release))
-	    self.cids.append(self.canvas.mpl_connect('draw_event', self.update_background))
-	if self.direction == 'horizontal':
+            self.cids.append(self.canvas.mpl_connect('button_release_event', self.release))
+            self.cids.append(self.canvas.mpl_connect('draw_event', self.update_background))
+        if self.direction == 'horizontal':
             trans = blended_transform_factory(self.ax.transData, self.ax.transAxes)
             w,h = 0,1
         else:
@@ -979,7 +1021,7 @@ class RectangleSelector:
     """
     Select a min/max range of the x axes for a matplotlib Axes
 
-    Example usage:
+    Example usage::
 
         from matplotlib.widgets import  RectangleSelector
         from pylab import *
@@ -1011,7 +1053,8 @@ class RectangleSelector:
     """
     def __init__(self, ax, onselect, drawtype='box',
                  minspanx=None, minspany=None, useblit=False,
-                 lineprops=None, rectprops=None):
+                 lineprops=None, rectprops=None, spancoords='data',
+                 button=None):
 
         """
         Create a selector in ax.  When a selection is made, clear
@@ -1035,7 +1078,21 @@ class RectangleSelector:
 
         Use type if you want the mouse to draw a line, a box or nothing
         between click and actual position ny setting
+
         drawtype = 'line', drawtype='box' or drawtype = 'none'.
+
+        spancoords is one of 'data' or 'pixels'.  If 'data', minspanx
+        and minspanx will be interpreted in the same coordinates as
+        the x and ya axis, if 'pixels', they are in pixels
+
+        button is a list of integers indicating which mouse buttons should
+        be used for rectangle selection.  You can also specify a single
+        integer if only a single button is desired.  Default is None, which
+        does not limit which button can be used.
+        Note, typically:
+         1 = left mouse button
+         2 = center mouse button (scroll wheel)
+         3 = right mouse button
         """
         self.ax = ax
         self.visible = True
@@ -1072,6 +1129,15 @@ class RectangleSelector:
         self.useblit = useblit
         self.minspanx = minspanx
         self.minspany = minspany
+
+        if button is None or isinstance(button, list):
+            self.validButtons = button
+        elif isinstance(button, int):
+            self.validButtons = [button]
+
+        assert(spancoords in ('data', 'pixels'))
+
+        self.spancoords = spancoords
         self.drawtype = drawtype
         # will save the data (position at mouseclick)
         self.eventpress = None
@@ -1094,6 +1160,12 @@ class RectangleSelector:
         if not self.canvas.widgetlock.available(self):
             return True
 
+        # Only do rectangle selection if event was triggered
+        # with a desired button
+        if self.validButtons is not None:
+            if not event.button in self.validButtons:
+                return True
+
         # If no button was pressed yet ignore the event if it was out
         # of the axes
         if self.eventpress == None:
@@ -1125,15 +1197,22 @@ class RectangleSelector:
         self.canvas.draw()
         # release coordinates, button, ...
         self.eventrelease = event
-        xmin, ymin = self.eventpress.xdata, self.eventpress.ydata
-        xmax, ymax = self.eventrelease.xdata, self.eventrelease.ydata
-        # calculate dimensions of box or line get values in the right
-        # order
+
+        if self.spancoords=='data':
+            xmin, ymin = self.eventpress.xdata, self.eventpress.ydata
+            xmax, ymax = self.eventrelease.xdata, self.eventrelease.ydata
+            # calculate dimensions of box or line get values in the right
+            # order
+        elif self.spancoords=='pixels':
+            xmin, ymin = self.eventpress.x, self.eventpress.y
+            xmax, ymax = self.eventrelease.x, self.eventrelease.y
+        else:
+            raise ValueError('spancoords must be "data" or "pixels"')
+
+
         if xmin>xmax: xmin, xmax = xmax, xmin
         if ymin>ymax: ymin, ymax = ymax, ymin
 
-
-
         spanx = xmax - xmin
         spany = ymax - ymin
         xproblems = self.minspanx is not None and spanx<self.minspanx
