@@ -1,8 +1,25 @@
-#include <png.h>
 
-// To remove a gcc warning
-#ifdef _POSIX_C_SOURCE
-#undef _POSIX_C_SOURCE
+/* For linux, png.h must be imported before Python.h because
+   png.h needs to be the one to define setjmp.
+   Undefining _POSIX_C_SOURCE and _XOPEN_SOURCE stops a couple
+   of harmless warnings.
+*/
+
+#ifdef __linux__
+#   include <png.h>
+#   ifdef _POSIX_C_SOURCE
+#       undef _POSIX_C_SOURCE
+#   endif
+#   ifdef _XOPEN_SOURCE
+#       undef _XOPEN_SOURCE
+#   endif
+#   include "Python.h"
+#else
+
+/* Python API mandates Python.h is included *first* */
+#   include "Python.h"
+
+#   include <png.h>
 #endif
 
 // TODO: Un CXX-ify this module
@@ -10,6 +27,11 @@
 #include "numpy/arrayobject.h"
 #include "mplutils.h"
 
+// As reported in [3082058] build _png.so on aix
+#ifdef _AIX
+#undef jmpbuf
+#endif
+
 // the extension module
 class _png_module : public Py::ExtensionModule<_png_module>
 {
@@ -146,7 +168,7 @@ Py::Object _png_module::write_png(const Py::Tuple& args)
             throw Py::RuntimeError("Could not create info struct");
         }
 
-        if (setjmp(png_ptr->jmpbuf))
+        if (setjmp(png_jmpbuf(png_ptr)))
         {
             throw Py::RuntimeError("Error building image");
         }
