@@ -1,8 +1,4 @@
-// To remove a gcc warning
-#ifdef _POSIX_C_SOURCE
-#undef _POSIX_C_SOURCE
-#endif
-
+/* Python API mandates Python.h is included *first* */
 #include "Python.h"
 #include <string>
 
@@ -392,7 +388,6 @@ Image::resize(const Py::Tuple& args, const Py::Dict& kwargs)
 
     // the image path
     agg::path_storage path;
-    agg::int8u *bufferPad = NULL;
     agg::rendering_buffer rbufPad;
 
     double x0, y0, x1, y1;
@@ -541,9 +536,7 @@ Image::resize(const Py::Tuple& args, const Py::Dict& kwargs)
 
     }
 
-    delete [] bufferPad;
     return Py::Object();
-
 }
 
 
@@ -927,7 +920,7 @@ _image_module::fromarray(const Py::Tuple& args)
 
         int rgba = A->dimensions[2] == 4;
         double r, g, b, alpha;
-        int offset = 0;
+        size_t offset = 0;
 
         for (size_t rownum = 0; rownum < imo->rowsIn; rownum++)
         {
