@@ -1,4 +1,4 @@
-/* mplutils.h	--
+/* mplutils.h   --
  *
  * $Header$
  * $Log$
@@ -20,7 +20,7 @@
 void _VERBOSE(const std::string&);
 
 
-#undef	CLAMP
+#undef  CLAMP
 #define CLAMP(x, low, high)  (((x) > (high)) ? (high) : (((x) < (low)) ? (low) : (x)))
 
 #undef  MAX
@@ -45,4 +45,27 @@ public :
     friend std::ostream &operator <<(std::ostream &, const Printf &);
 };
 
+#if defined(_MSC_VER) && (_MSC_VER == 1400)
+
+/* Required by libpng and zlib */
+#pragma comment(lib, "bufferoverflowU")
+
+/* std::max and std::min are missing in Windows Server 2003 R2
+   Platform SDK compiler.  See matplotlib bug #3067191 */
+namespace std {
+
+    template <class T> inline T max(const T& a, const T& b)
+    {
+        return (a > b) ? a : b;
+    }
+
+    template <class T> inline T min(const T& a, const T& b)
+    {
+        return (a < b) ? a : b;
+    }
+
+}
+
+#endif
+
 #endif
